@@ -11,7 +11,7 @@ use vars qw[ $VERSION ];
 
 use IO::File;
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.12 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.13 $ =~ /: (\d+)\.(\d+)/;
 
 # Prevents death later on if IO::File can't export this constant.
 BEGIN
@@ -165,9 +165,9 @@ Dave Rolsky, <autarch@urth.org>
 
 =head1 SEE ALSO
 
-Log::Dispatch, Log::Dispatch::Email, Log::Dispatch::Email::MailSend,
-Log::Dispatch::Email::MailSendmail, Log::Dispatch::Email::MIMELite,
-Log::Dispatch::Handle, Log::Dispatch::Output, Log::Dispatch::Screen,
-Log::Dispatch::Syslog
+Log::Dispatch, Log::Dispatch::ApacheLog, Log::Dispatch::Email,
+Log::Dispatch::Email::MailSend, Log::Dispatch::Email::MailSendmail,
+Log::Dispatch::Email::MIMELite, Log::Dispatch::Handle,
+Log::Dispatch::Output, Log::Dispatch::Screen, Log::Dispatch::Syslog
 
 =cut
